#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_aitx
----------------------------------

Tests for `aitx` module.
"""

import unittest

from aitx import aitx


class TestAitx(unittest.TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass
